==> kdebase_2.2.2.orig.tar.gz: kdebase-2.2.2/kdesktop/xautolock.h <==
//===========================================================================
//
// This file is part of the KDE project
//
// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
//

#ifndef __XAUTOLOCK_H__
#define __XAUTOLOCK_H__

#include <time.h>
#include <qobject.h>
#include <qqueue.h>
#include <X11/Xlib.h>

//===========================================================================
//
// A window and its creation time.
//
class WatchedWindow
{
public:
    WatchedWindow(Window w)
        { mWindow = w; mTime = time(0); }

    time_t created() { return mTime; }
    Window window() { return mWindow; }

protected:
    Window mWindow;
    time_t mTime;
};

//===========================================================================
//
// Detect user inactivity.
// Named XAutoLock after the program that it is based on.
//
class XAutoLock : public QObject
{
    Q_OBJECT
public:
    XAutoLock();
    ~XAutoLock();

    //-----------------------------------------------------------------------
    //
    // The time in seconds of continuous inactivity.
    //
    void setTimeout(int t);

    //-----------------------------------------------------------------------
    //
    // Start watching Activity
    //
    void start();

    //-----------------------------------------------------------------------
    //
    // Stop watching Activity
    //
    void stop();

public slots:
    void windowCreated(Window w);
    void keyPressed();

signals:
    void timeout();

protected:
    void resetTrigger();
    void processWatched(time_t delay);
    void selectEvents(Window window, bool substructure_only);
    void queryPointer();
    virtual void timerEvent(QTimerEvent *ev);

protected:
    int     mTimerId;
    int     mTimeout;
    int     mTrigger;
    bool    mActive;
    time_t  mLastTimeout;
    QQueue<WatchedWindow>  mWindows;
};

#endif

==> kdebase_3.5.9.orig.tar.gz: kdebase-3.5.9.orig/kdesktop/xautolock.h <==
//===========================================================================
//
// This file is part of the KDE project
//
// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
//

#ifndef __XAUTOLOCK_H__
#define __XAUTOLOCK_H__

#include <qwidget.h>

#include <X11/Xlib.h>

//===========================================================================
//
// Detect user inactivity.
// Named XAutoLock after the program that it is based on.
//
class XAutoLock : public QWidget
{
    Q_OBJECT
public:
    XAutoLock();
    ~XAutoLock();

    //-----------------------------------------------------------------------
    //
    // The time in seconds of continuous inactivity.
    //
    void setTimeout(int t);
    
    void setDPMS(bool s);
    
    //-----------------------------------------------------------------------
    //
    // Start watching Activity
    //
    void start();

    //-----------------------------------------------------------------------
    //
    // Stop watching Activity
    //
    void stop();

    //-----------------------------------------------------------------------
    //
    // Should be called only from a slot connected to the timeout() signal. Will
    // result in the timeout() signal being emitted again with a delay (i.e. postponed).
    //
    void postpone();

    // internal
    void resetTrigger();
    // internal
    void setTrigger( time_t );
    // internal
    bool ignoreWindow( WId );
    
signals:
    void timeout();

protected:
    virtual void timerEvent(QTimerEvent *ev);
    virtual bool x11Event( XEvent* );

protected:
    int     mTimerId;
    int     mTimeout;
    time_t  mTrigger;
    bool    mActive;
    time_t  mLastTimeout;
    bool    mDPMS;
};

#endif
